@@ -1,5 +1,4 @@
-import mimetypes
-import urllib
+import mimetypes, urllib, os
 
 from zope.interface import implements, Interface
 from interfaces import IFileMutator
@@ -125,6 +124,12 @@ class AddImage(BrowserView):
         context = aq_inner(self.context)
         return context.translate(msg, domain="xhostplus.gallery")
 
+    def _clean_filename(self, filename):
+        filename, fileext = os.path.splitext(filename)
+        filename = filename.replace("_", " ")
+        filename = filename.capitalize()
+        return filename
+
     def __init__(self, context, request):
         self.context = context
         self.request = request
@@ -150,6 +155,7 @@ class AddImage(BrowserView):
                 return json.dumps({u'error': _(u"An unknown server error occurred")})
 
         content_type = mimetypes.guess_type(file_name)[0] or ""
+        file_name = self._clean_filename(file_name)
 
         # call all file mutator utilities
         for mutator in component.getAllUtilitiesRegisteredFor(IFileMutator):
