@@ -9,10 +9,14 @@ from plone.portlets.interfaces import IPortletDataProvider
 from zope import schema
 from zope.formlib import form
 from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary
-from zope.app.schema.vocabulary import IVocabularyFactory
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.CMFCore.utils import getToolByName
 
+try:
+    from zope.schema.interfaces import IVocabularyFactory
+except:
+    from zope.app.schema.vocabulary import IVocabularyFactory
+
 from xhostplus.gallery import galleryMessageFactory as _
 
 class IGalleryPortlet(IPortletDataProvider):
@@ -60,7 +64,7 @@ class Assignment(base.Assignment):
         catalog = getToolByName(context, 'portal_catalog') # getting the catalog for searching objects
         result = catalog(portal_type='Image Gallery',
                          path={
-                             'query': self.path, 
+                             'query': self.path,
                              'depth': 0,
                          })
 
@@ -74,7 +78,7 @@ class Assignment(base.Assignment):
         catalog = getToolByName(context, 'portal_catalog') # getting the catalog for searching objects
         results = catalog(portal_type='Image',
                          path={
-                             'query': self.path, 
+                             'query': self.path,
                              'depth': 1,
                          })
 
